@@ -12,6 +12,7 @@ use Net::Etcd::Auth;
 use Net::Etcd::Config;
 use Net::Etcd::Watch;
 use Net::Etcd::Lease;
+use Net::Etcd::Maintenance;
 use Net::Etcd::User;
 use Types::Standard qw(Str Int Bool HashRef);
 
@@ -27,7 +28,7 @@ Net::Etcd
 
 =cut
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 =head1 SYNOPSIS
 
@@ -66,7 +67,7 @@ our $VERSION = '0.009';
 
 =head1 DESCRIPTION
 
-This module has been superseded by L<Net::Etcd> and will be removed from CPAN on June 29th 2017
+L<Net::Etcd> is object oriented interface to the v3 REST API provided by the etcd L<grpc-gateway|https://github.com/grpc-ecosystem/grpc-gateway>.
 
 
 =head1 ACCESSORS
@@ -257,6 +258,22 @@ sub lease {
     );
 }
 
+=head2 maintenance
+
+Returns a L<Net::Etcd::Maintenance> object.
+
+=cut
+
+sub maintenance {
+    my ( $self, $options ) = @_;
+    my $cb = pop if ref $_[-1] eq 'CODE';
+    return Net::Etcd::Maintenance->new(
+        etcd => $self,
+        cb   => $cb,
+        ( $options ? %$options : () ),
+    );
+}
+
 =head2 user
 
 Returns a L<Net::Etcd::User> object.
